****************
Executor modules
****************

.. automodule:: orion.executor
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Executor modules of Oríon

   executor/base
   executor/dask
   executor/joblib
